@@ -16,16 +16,15 @@ __all__ = ['RpcHandler', 'RpcMiddleware']
 
 LOGGER = logging.getLogger('pulsar.rpc')
 
-LOGGER = logging.getLogger('pulsar.rpc')
 
-
-class RpcRequest(object):
+class RpcRequest:
 
     def __init__(self, environ):
         self.environ = environ
 
     def __repr__(self):
         return self.rpc.method
+    __str__ = __repr__
 
     def __getattr__(self, name):
         return self.environ.get(name)
@@ -278,8 +277,6 @@ class RpcMiddleware(object):
     The path where the RPC is located
 
     Default ``None``
-
-.. _WSGI:: http://www.wsgi.org/
 '''
     methods = ('get','post','put','head','delete','trace','connect')
     request_class = RpcRequest
