@@ -1,19 +1,26 @@
 import os
+import sys
 import json
 import textwrap
 import logging
-from functools import partial
+import time
+from datetime import datetime, timedelta
+from functools import partial, reduce
+from email.utils import formatdate
 
 import pulsar
 from pulsar import maybe_async, is_async, is_failure, log_failure, NOT_DONE
-from pulsar.utils.httpurl import Headers, SimpleCookie, set_cookie, responses,\
+from pulsar.utils.httpurl import Headers, SimpleCookie, responses,\
                                  has_empty_content, string_type, ispy3k,\
                                  to_bytes, REDIRECT_CODES
 
 from .middleware import is_streamed
 
-if ispy3k:
-    from functools import reduce
+if ispy3k:  #thanks to @chrismcdonoug
+    from urllib.parse import unquote_to_bytes
+    unquote_to_bytes_wsgi = lambda bs: unquote_to_bytes(bs).decode('latin-1')
+else:   #pragma    nocover
+    from urlparse import unquote as unquote_to_bytes_wsgi
 
 __all__ = ['WsgiHandler',
            'WsgiResponse',
@@ -48,6 +55,51 @@ def wsgi_iterator(gen, encoding=None):
                 for b in wsgi_iterator(data, encoding):
                     yield b
 
+def cookie_date(epoch_seconds=None):
+    """Formats the time to ensure compatibility with Netscape's cookie
+    standard.
+
+    Accepts a floating point number expressed in seconds since the epoch in, a
+    datetime object or a timetuple.  All times in UTC.  The :func:`parse_date`
+    function can be used to parse such a date.
+
+    Outputs a string in the format ``Wdy, DD-Mon-YYYY HH:MM:SS GMT``.
+
+    :param expires: If provided that date is used, otherwise the current.
+    """
+    rfcdate = formatdate(epoch_seconds)
+    return '%s-%s-%s GMT' % (rfcdate[:7], rfcdate[8:11], rfcdate[12:25])
+
+def set_cookie(cookies, key, value='', max_age=None, expires=None, path='/',
+                domain=None, secure=False, httponly=False):
+    '''Set a cookie key into the cookies dictionary *cookies*.'''
+    cookies[key] = value
+    if expires is not None:
+        if isinstance(expires, datetime):
+            delta = expires - expires.utcnow()
+            # Add one second so the date matches exactly (a fraction of
+            # time gets lost between converting to a timedelta and
+            # then the date string).
+            delta = delta + timedelta(seconds=1)
+            # Just set max_age - the max_age logic will set expires.
+            expires = None
+            max_age = max(0, delta.days * 86400 + delta.seconds)
+        else:
+            cookies[key]['expires'] = expires
+    if max_age is not None:
+        cookies[key]['max-age'] = max_age
+        # IE requires expires, so set it if hasn't been already.
+        if not expires:
+            cookies[key]['expires'] = cookie_date(time.time() + max_age)
+    if path is not None:
+        cookies[key]['path'] = path
+    if domain is not None:
+        cookies[key]['domain'] = domain
+    if secure:
+        cookies[key]['secure'] = True
+    if httponly:
+        cookies[key]['httponly'] = True
+        
 
 class WsgiResponseGenerator(object):
 
@@ -131,9 +183,14 @@ client.
     def _set_content(self, content):
         if not self._started:
             if content is None:
-                # no content, get the default content
-                content = self.default_content()
-            elif isinstance(content, bytes):
+                content = ()
+            elif ispy3k: #what a fucking pain
+                if isinstance(content, str):
+                    content = bytes(content, 'latin-1')
+            else: #pragma    nocover
+                if isinstance(content, unicode):
+                    content = bytes(content, 'latin-1')
+            if isinstance(content, bytes):
                 content = (content,)
             self._content = content
         else:
@@ -149,11 +206,6 @@ client.
             self.headers.pop('content-type', None)
     content_type = property(_get_content_type, _set_content_type)
 
-    def default_content(self):
-        '''Called during initialization when the content given is ``None``.
-By default it returns an empty tuple. Overrides if you need to.'''
-        return ()
-
     def __call__(self, environ, start_response, exc_info=None):
         '''Make sure the headers are set.'''
         if not exc_info:
@@ -358,7 +410,5 @@ def handle_wsgi_error(environ, trace=None, content_type=None,
                          "version": pulsar.SERVER_SOFTWARE})
         else:
             content = wsgi_error_msg(response, msg)
-    if not isinstance(content, (tuple, list)):
-        content = to_bytes(content, response.encoding or 'utf-8', 'replace')
     response.content = content
     return response
\ No newline at end of file
